import {useDispatch, useSelector} from "react-redux";

import Modal from "../components/Modal";
import ModalDetails from "../components/ModalDetails";
import logo from "../shared/img/logo_modal.png"
import {generalSelector, rewardsSelector} from "../store/selectors";
import {fetchRewardCount, fetchRewards} from "../store/reducers/rewards/rewardsThunksAction";
import {openCloseModal, setType} from "../store/reducers/general/generalSlice";

import "./styles.scss";
import {useEffect} from "react";
import {fetchShopName} from "../store/reducers/general/generalThunksAction";

const Dashboard = () => {
    const {isOpen, type, shopName, user} = useSelector(generalSelector);
    const {rewardCount} = useSelector(rewardsSelector);

    const dispatch = useDispatch();
    const host = window.location.hostname;

    const openModal = () => {
        if (user) {
            dispatch(fetchRewards({email: user, shop: host}));
        }

        dispatch(openCloseModal(!isOpen))
        dispatch(setType(null));
    };

    useEffect(() => {
        if (user && !isOpen) {
            dispatch(fetchRewardCount({email: user, shop: host }))
        }
    });

    useEffect(() => {
        dispatch(fetchShopName());
    }, [shopName]);

    return (
        <>
            {type && <ModalDetails isLogin={!!user} openModal={openModal}/>}
            {isOpen && !type && <Modal isLogin={!!user} openModal={openModal}/>}
            <div className="rewards--wrapper">
                {(!!rewardCount && !isOpen) && <div className="rewardCount">{rewardCount}</div>}
                <div className={`rewards--btn ${isOpen ? "openBlock" : "closeBlock"}`}
                     onClick={openModal}>
                    <div className="reward--btn">
                        <img src={logo} alt="Lynked Loyalty Logo"/>
                        <span>Loyalty Club</span>
                    </div>
                    <div className="close-btn">
                        <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 20 20">
                            <path fill="rgb(255, 255, 255)"
                                  d="M11.06 10l3.713 3.712a.75.75 0 0 1-1.06 1.061L10 11.061l-3.712 3.712a.75.75 0 0 1-1.061-1.06L8.939 10 5.227 6.288a.75.75 0 1 1 1.06-1.061L10 8.939l3.712-3.712a.75.75 0 0 1 1.061 1.06L11.061 10z"/>
                        </svg>
                    </div>
                </div>
            </div>
        </>
    );
}

export default Dashboard;
