import {useDispatch, useSelector} from "react-redux";

import {Activity} from "../../shared/icons/activity";
import {Redeem} from "../../shared/icons/redeem";
import {Earn} from "../../shared/icons/earn";
import logo from "../../shared/img/logo_modal.png"
import DownloadApp from "../DownloadApp";
import Title from "../Title";
import PointWay from "../PointWay";
import {Arrow} from "../../shared/icons/arrow";
import {generalSelector, rewardsSelector} from "../../store/selectors";

import "./styles.scss";
import {setType} from "../../store/reducers/general/generalSlice";
import {Close} from "../../shared/icons/close";
import CloseModal from "../CloseModal";

const Modal = ({isLogin, openModal}) => {
    const dispatch = useDispatch();
    const {points, vouchers} = useSelector(rewardsSelector);
    const {shopName} = useSelector(generalSelector);
    const {rewardCount} = useSelector(rewardsSelector);

    const handleCLick = (type) => {
        dispatch(setType(type));
    }

    return (
        <div className="reward-block main-reward-block view-block">
            <div className="reward--header">
                <CloseModal openModal={openModal}/>

                {isLogin ?
                    <div>
                        <h4>Your {shopName} points!</h4>
                        <div className="point-logo-wrapper">
                            <h2 className="pointsBlock">{points}</h2>
                            <img src={logo} alt="Lynked Loyalty Logo"/>
                        </div>
                    </div>
                    :
                    <div>
                        <h4>Welcome to</h4>
                        <h2>{shopName}</h2>
                    </div>
                }
            </div>
            <div className="reward-content">
                {!isLogin ?
                    <>
                        <div className="reward-inside-block">
                            <div className="title">Join our loyalty program</div>
                            <p className="card-description">Use Lynked Loyalty to collect rewards everytime you
                                shop.</p>
                            <a href="/my-account/" className="joinNow">Join now</a>
                            <p className="card-description">Already have an
                                account?<a
                                    href="/my-account/">Sign in</a></p>
                        </div>
                        <DownloadApp onClick={handleCLick}/>
                    </>
                    : !!vouchers.length && <>
                    {!!rewardCount && <div className="rewardCount rewardCountSmall">{rewardCount}</div>}
                        <div className="reward-inside-block voucher--wrapper">
                            <div className="pointWays" onClick={() => handleCLick("vouchers")}>
                                <div className="vouchers-action-wrapper">
                                    <Title text="Your vouchers"/>
                                    <div className="card-description">You
                                        have {vouchers.length} reward{vouchers.length > 1 ? 's' : ''}
                                    </div>
                                </div>
                                <Arrow/>
                            </div>
                        </div>
                    </>
                }

                <div className="reward-inside-block">
                    {isLogin ||
                        <>
                            <div className="title">Earn Points</div>
                            <p className="card-description">Earn points for spending online or in store with
                                businesses using Lynked. Turn those points into excellent rewards!</p>
                        </>
                    }
                    <div className="pointWays--wrapper">
                        <PointWay text="How to earn points" type="earn" icon={<Earn/>} onCLick={handleCLick}/>
                        <PointWay text="How to redeem rewards" type="redeem" icon={<Redeem/>} onCLick={handleCLick}/>
                    </div>
                </div>
                {isLogin &&
                    <>
                        <DownloadApp onClick={handleCLick}/>

                        <div className="reward-inside-block">
                            <PointWay text="Your activity" icon={<Activity/>} onCLick={handleCLick} type="activity"/>
                        </div>
                    </>
                }
            </div>
            <div className="reward-footer">
                <p className="card-description">We reward with Lynked Loyalty</p>
            </div>
        </div>
    );
};

export default Modal;